@@ -1,4 +1,4 @@
-void linkcallbacks();
+void callbackslink();
 
 void on_ejectmedia_clicked(GtkWidget *widget, gpointer user_data);
 
@@ -10,6 +10,8 @@ void on_blankfull_clicked(GtkWidget *widget, gpointer user_data);
 
 void on_fileburn_clicked(GtkWidget *widget, gpointer user_data);
 
+void on_audioburn_clicked(GtkWidget *widget, gpointer user_data);
+
 void on_dirburn_clicked(GtkWidget *widget, gpointer user_data);
 
 void on_tracks_row_activated(GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
@@ -21,3 +23,9 @@ void on_previewvideo_clicked(GtkWidget *widget, gpointer user_data);
 void on_extractvideo_clicked(GtkWidget *widget, gpointer user_data);
 
 void on_extractiso_clicked(GtkWidget *widget, gpointer user_data);
+
+void on_detectmedia_clicked(GtkWidget *widget, gpointer user_data);
+
+void on_videotitle_changed(GtkWidget *widget, gpointer user_data);
+
+void reset_mediadetection();
